@@ -30,7 +30,7 @@ class LabelsMixin(object):
     """
     def _process_labels(self, param_name, param_value, dry_run=False, skip_save=False):
         assert param_name == 'labels'  # noqa: S101
-        assert skip_save == False  # noqa: S101
+        assert not skip_save  # noqa: S101
         unknown_labels = self._content.get('unknown_labels', 'warn')
         try:
             current_labels = dict([[current_label.name, current_label]
