@@ -25,7 +25,16 @@ try:
 except ImportError:
     from urllib.parse import quote, urlparse  # Python 3+
 
-from pygit2 import GIT_FETCH_PRUNE, GitError, LIBGIT2_VER, RemoteCallbacks, Repository, UserPass, init_repository
+from pygit2 import (
+    GIT_FETCH_PRUNE,
+    GitError,
+    LIBGIT2_VER,
+    Passthrough,
+    RemoteCallbacks,
+    Repository,
+    UserPass,
+    init_repository,
+)
 
 import gitlabracadabra.manager
 import gitlabracadabra.utils
@@ -34,13 +43,19 @@ logger = logging.getLogger(__name__)
 
 
 class PyGit2Callbacks(RemoteCallbacks):
+    def __init__(self, use_token):
+        self._use_token = use_token
+
     """"credentials()
 
     Authenticate using OAuth2 token
     """
     def credentials(self, url, username_from_url, allowed_types):
-        mgr = gitlabracadabra.manager.get_manager()
-        return UserPass('oauth2', mgr.private_token)
+        if self._use_token:
+            mgr = gitlabracadabra.manager.get_manager()
+            return UserPass('oauth2', mgr.private_token)
+        else:
+            raise Passthrough
 
 
 class MirrorsMixin(object):
@@ -50,7 +65,7 @@ class MirrorsMixin(object):
     """
     def _process_mirrors(self, param_name, param_value, dry_run=False, skip_save=False):
         assert param_name == 'mirrors'  # noqa: S101
-        assert skip_save == False  # noqa: S101
+        assert not skip_save  # noqa: S101
 
         def init_repo():
             repo_dir = gitlabracadabra.utils.gitlabracadabra_cache_dir(quote(self.web_url(), safe=''))
@@ -96,12 +111,12 @@ class MirrorsMixin(object):
                 logger.warning('[%s] Using git command to fetch remote %s', self._name, name)
                 subprocess.run(['git', 'fetch', '--quiet', '--prune', name], cwd=self._repo.path)  # noqa: S603,S607
             else:
-                pygit2_callbacks = PyGit2Callbacks()
+                pygit2_callbacks = PyGit2Callbacks(use_token=name == 'gitlab')
                 self._repo.remotes[name].fetch(refspecs=self._repo.remotes[name].fetch_refspecs,
                                                callbacks=pygit2_callbacks, prune=GIT_FETCH_PRUNE)
 
         def push_remote(name, refs):
-            pygit2_callbacks = PyGit2Callbacks()
+            pygit2_callbacks = PyGit2Callbacks(use_token=name == 'gitlab')
             try:
                 self._repo.remotes[name].push(refs, callbacks=pygit2_callbacks)
             except GitError as e:
