@@ -26,6 +26,7 @@ from gitlabracadabra.mixins.members import MembersMixin
 from gitlabracadabra.mixins.milestones import MilestonesMixin
 from gitlabracadabra.mixins.mirrors import MirrorsMixin
 from gitlabracadabra.mixins.variables import VariablesMixin
+from gitlabracadabra.mixins.webhooks import WebhooksMixin
 from gitlabracadabra.objects.group import GitLabracadabraGroup
 from gitlabracadabra.objects.object import GitLabracadabraObject
 from gitlabracadabra.utils import access_level
@@ -35,7 +36,7 @@ logger = logging.getLogger(__name__)
 
 
 class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, MilestonesMixin, MirrorsMixin,
-                             VariablesMixin):
+                             VariablesMixin, WebhooksMixin):
     EXAMPLE_YAML_HEADER = 'mygroup/myproject:\n'
     DOC = [
         '# Project lifecycle',
@@ -49,29 +50,34 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
         'name',
         'tag_list',
         'description',
-        # 'avatar',  # FIXME
+        # 'avatar',  # FIXME Gitlabracadabra
         '## Visibility, project features, permissions',
         'visibility',
         'request_access_enabled',
         'issues_access_level',
         'repository_access_level',
         'merge_requests_access_level',
+        'forking_access_level',
         'builds_access_level',
         'container_registry_enabled',
         'lfs_enabled',
+        # 'metrics_dashboard_access_level',  # FIXME Gitlab
         'packages_enabled',
         'wiki_access_level',
         'snippets_access_level',
-        # 'pages_access_level',  # FIXME
-        # 'emails_disabled',  # FIXME
+        'pages_access_level',
+        'emails_disabled',
+        # 'show_default_award_emojis',  # FIXME Gitlab
         '## Merge requests',
         'merge_method',
-        # 'merge_pipelines_enabled',  # FIXME
+        # 'merge_pipelines_enabled',  # FIXME Gitlab
         'resolve_outdated_diff_discussions',
         'printing_merge_request_link_enabled',
         'remove_source_branch_after_merge',
         'only_allow_merge_if_pipeline_succeeds',
+        'allow_merge_on_skipped_pipeline',
         'only_allow_merge_if_all_discussions_are_resolved',
+        'suggestion_commit_message',
         # 'merge_requests_template',  # FIXME
         '## Merge request approvals',  # FIXME ...
         'approvals_before_merge',
@@ -87,9 +93,14 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
 
         # '# Integrations',  # FIXME
 
+        '# Webhooks',
+        'webhooks',
+        'unknown_webhooks',
+
         '# Repository Settings',
         '## Default branch',
         'default_branch',
+        'autoclose_referenced_issues',
         # '## Push Rules',  # FIXME ...
         '## Mirroring repositories',
         'mirrors',
@@ -118,6 +129,7 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
         'ci_config_path',
         'public_builds',
         'auto_cancel_pending_pipelines',
+        # 'forward_deployment_enabled',  # FIXME Gitlab
         'build_coverage_regex',
         '## Auto DevOps',
         'auto_devops_enabled',
@@ -158,8 +170,18 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
                 "type": "boolean",
                 "description": "Delete object if it exists",
             },
+            # https://docs.gitlab.com/ee/api/projects.html#archive-a-project
+            # https://docs.gitlab.com/ee/api/projects.html#unarchive-a-project
+            "archived": {
+                "type": "boolean",
+                "description": "Archive or unarchive project",
+            },
             # From https://docs.gitlab.com/ee/api/projects.html#create-project
             # and https://docs.gitlab.com/ee/api/projects.html#edit-project
+            "initialize_with_readme": {
+                "type": "boolean",
+                "description": "false by default",
+            },
             "name": {
                 "type": "string",
                 "description": "Project name",
@@ -183,10 +205,10 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
                 "description": "Project description",
                 "_example": "|-\n    🧹 GitLabracadabra 🧙\n\n    :alembic: Adds some magic to GitLab :crystal\\_ball:"
             },
-            "avatar": {
-                "type": "string",
-                "description": "Project avatar",
-            },
+            # "avatar": {
+            #     "type": "string",
+            #     "description": "Project avatar",
+            # },
             "visibility": {
                 "type": "string",
                 "description": "Project visibility",
@@ -196,30 +218,6 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
                 "type": "boolean",
                 "description": "Allow users to request access",
             },
-            "default_branch": {
-                "type": "string",
-                "description": "`master` by default",
-            },
-            "issues_enabled": {
-                "type": "boolean",
-                "description": "Enable issues for this project",
-            },
-            "merge_requests_enabled": {
-                "type": "boolean",
-                "description": "Enable merge requests for this project",
-            },
-            "jobs_enabled": {
-                "type": "boolean",
-                "description": "Enable jobs for this project",
-            },
-            "wiki_enabled": {
-                "type": "boolean",
-                "description": "Enable wiki for this project",
-            },
-            "snippets_enabled": {
-                "type": "boolean",
-                "description": "Enable snippets for this project",
-            },
             "issues_access_level": {
                 "type": "string",
                 "description": "Issues access level.",
@@ -235,11 +233,28 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
                 "description": "Merge requests access level.",
                 "enum": ["disabled", "private", "enabled"],
             },
+            "forking_access_level": {
+                "type": "string",
+                "description": "Forking access level.",
+                "enum": ["disabled", "private", "enabled"],
+            },
             "builds_access_level": {
                 "type": "string",
                 "description": "Builds access level.",
                 "enum": ["disabled", "private", "enabled"],
             },
+            "container_registry_enabled": {
+                "type": "boolean",
+                "description": "Enable container registry for this project",
+            },
+            "lfs_enabled": {
+                "type": "boolean",
+                "description": "Enable LFS",
+            },
+            "packages_enabled": {
+                "type": "boolean",
+                "description": "Enable or disable packages repository feature",
+            },
             "wiki_access_level": {
                 "type": "string",
                 "description": "Wiki access level.",
@@ -250,90 +265,47 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
                 "description": "Snippets access level.",
                 "enum": ["disabled", "private", "enabled"],
             },
-            "resolve_outdated_diff_discussions": {
-                "type": "boolean",
-                "description": "Automatically resolve merge request diffs discussions on lines changed with a push",
-            },
-            "container_registry_enabled": {
-                "type": "boolean",
-                "description": "Enable container registry for this project",
-            },
-            "shared_runners_enabled": {
-                "type": "boolean",
-                "description": "Enable shared runners for this project",
-            },
-            "import_url": {
+            "pages_access_level": {
                 "type": "string",
-                "description": "URL to import repository from",
+                "description": "Forking access level.",
+                "enum": ["disabled", "private", "enabled", "public"],
             },
-            "public_builds": {
+            "emails_disabled": {
                 "type": "boolean",
-                "description": "If true, jobs can be viewed by non-project-members",
-            },
-            "only_allow_merge_if_pipeline_succeeds": {
-                "type": "boolean",
-                "description": "Set whether merge requests can only be merged with successful jobs",
-            },
-            "only_allow_merge_if_all_discussions_are_resolved": {
-                "type": "boolean",
-                "description": "Set whether merge requests can only be merged when all the discussions are resolved",
+                "description": "Disable email notifications",
             },
             "merge_method": {
                 "type": "string",
                 "description": "Set the merge method used",
                 "enum": ["merge", "rebase_merge", "ff"],
             },
-            "remove_source_branch_after_merge": {
+            "resolve_outdated_diff_discussions": {
                 "type": "boolean",
-                "description": "Enable Delete source branch option by default for all new merge requests",
-            },
-            "lfs_enabled": {
-                "type": "boolean",
-                "description": "Enable LFS",
+                "description": "Automatically resolve merge request diffs discussions on lines changed with a push",
             },
             "printing_merge_request_link_enabled": {
                 "type": "boolean",
                 "description": "Show link to create/view merge request when pushing from the command line",
             },
-            "build_git_strategy": {
-                "type": "string",
-                "description": "The Git strategy",
-                "enum": ["fetch", "clone"],
-            },
-            "build_timeout": {
-                "type": "integer",
-                "description": "The maximum amount of time in minutes that a job is able run (in seconds)",
-            },
-            "auto_cancel_pending_pipelines": {
-                "type": "string",
-                "description": "Auto-cancel pending pipelines",
-                "enum": ["enabled", "disabled"],
-            },
-            "build_coverage_regex": {
-                "type": "string",
-                "description": "Test coverage parsing",
-            },
-            "ci_config_path": {
-                "type": "string",
-                "description": "The path to CI config file",
-                "_example": 'debian/salsa-ci.yml'
-            },
-            "ci_default_git_depth": {
-                "type": "integer",
-                "description": "Default number of revisions for shallow cloning",
-            },
-            "auto_devops_enabled": {
+            "remove_source_branch_after_merge": {
                 "type": "boolean",
-                "description": "Enable Auto DevOps for this project",
+                "description": "Enable Delete source branch option by default for all new merge requests",
             },
-            "auto_devops_deploy_strategy": {
-                "type": "string",
-                "description": "Auto Deploy strategy",
-                "enum": ["continuous", "manual", "timed_incremental"],
+            "only_allow_merge_if_pipeline_succeeds": {
+                "type": "boolean",
+                "description": "Set whether merge requests can only be merged with successful jobs",
             },
-            "repository_storage": {
+            "allow_merge_on_skipped_pipeline": {
+                "type": "boolean",
+                "description": "Set whether or not merge requests can be merged with skipped jobs",
+            },
+            "only_allow_merge_if_all_discussions_are_resolved": {
+                "type": "boolean",
+                "description": "Set whether merge requests can only be merged when all the discussions are resolved",
+            },
+            "suggestion_commit_message": {
                 "type": "string",
-                "description": "Which storage shard the repository is on. Available only to admins",
+                "description": "The commit message used to apply merge request suggestions",
             },
             "approvals_before_merge": {
                 "type": "integer",
@@ -341,48 +313,24 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
                 "multipleOf": 1,
                 "minimum": 0,
             },
-            "external_authorization_classification_label": {
-                "type": "string",
-                "description": "The classification label for the project",
-            },
-            "mirror": {
-                "type": "boolean",
-                "description": "Enables pull mirroring in a project",
-            },
-            "mirror_user_id": {
-                "type": "integer",
-                "description": "User responsible for all the activity surrounding a pull mirror event",
-            },
-            "mirror_trigger_builds": {
-                "type": "boolean",
-                "description": "Pull mirroring triggers builds",
-            },
-            "only_mirror_protected_branches": {
-                "type": "boolean",
-                "description": "Only mirror protected branches",
-            },
-            "mirror_overwrites_diverged_branches": {
-                "type": "boolean",
-                "description": "Pull mirror overwrites diverged branches",
-            },
-            "packages_enabled": {
-                "type": "boolean",
-                "description": "Enable or disable packages repository feature",
-            },
-            "initialize_with_readme": {
-                "type": "boolean",
-                "description": "false by default",
-            },
-            # From https://docs.gitlab.com/ee/api/branches.html#create-repository-branch
-            "branches": {
-                "type": "array",
-                "description": "The list of branches for a project. "
-                               "Branches are created in order.",
-                "items": {
+            # From https://docs.gitlab.com/ee/api/members.html#add-a-member-to-a-group-or-project
+            # FIXME expires_at not supported
+            "members": {
+                "type": "object",
+                "description": "Members",
+                "additionalProperties": {
                     "type": "string",
+                    "description": "The permissions level to grant the member.",
+                    "enum": ["guest", "reporter", "developer", "maintainer", "owner"],
                 },
-                "uniqueItems": True,
-                "_example": "\n    - master\n    - develop"
+                "_example": ("\n"
+                             "    foo: developer\n"
+                             "    bar: maintainer # one of guest, reporter, developer, maintainer, owner\n"),
+            },
+            "unknown_members": {  # GitLabracadabra
+                "type": "string",
+                "description": "What to do with unknown members (`warn` by default).",
+                "enum": ["warn", "delete", "remove", "ignore", "skip"],
             },
             # From https://docs.gitlab.com/ee/api/projects.html#share-project-with-group_access_level
             # and https://docs.gitlab.com/ee/api/projects.html#delete-a-shared-project-link-within-a-group
@@ -404,25 +352,161 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
                 "description": "What to do with unknown groups (`warn` by default).",
                 "enum": ["warn", "delete", "remove", "ignore", "skip"],
             },
-            # From https://docs.gitlab.com/ee/api/members.html#add-a-member-to-a-group-or-project
-            # FIXME expires_at not supported
-            "members": {
-                "type": "object",
-                "description": "Members",
-                "additionalProperties": {
-                    "type": "string",
-                    "description": "The permissions level to grant the member.",
-                    "enum": ["guest", "reporter", "developer", "maintainer", "owner"],
+            # From https://docs.gitlab.com/ee/api/projects.html#hooks
+            "webhooks": {
+                "type": "array",
+                "description": "The list of project's webhooks",
+                "items": {
+                    "type": "object",
+                    "properties": {
+                        "url": {
+                            "type": "string",
+                            "description": "The hook URL",
+                        },
+                        "push_events": {
+                            "type": "boolean",
+                            "description": "Trigger hook on push events",
+                        },
+                        "push_events_branch_filter": {
+                            "type": "string",
+                            "description": "Trigger hook on push events for matching branches only",
+                        },
+                        "issues_events": {
+                            "type": "boolean",
+                            "description": "Trigger hook on issues events",
+                        },
+                        "confidential_issues_events": {
+                            "type": "boolean",
+                            "description": "Trigger hook on confidential issues events",
+                        },
+                        "merge_requests_events": {
+                            "type": "boolean",
+                            "description": "Trigger hook on merge requests events",
+                        },
+                        "tag_push_events": {
+                            "type": "boolean",
+                            "description": "Trigger hook on tag push events",
+                        },
+                        "note_events": {
+                            "type": "boolean",
+                            "description": "Trigger hook on note events",
+                        },
+                        "confidential_note_events": {
+                            "type": "boolean",
+                            "description": "Trigger hook on confidential note events",
+                        },
+                        "job_events": {
+                            "type": "boolean",
+                            "description": "Trigger hook on job events",
+                        },
+                        "pipeline_events": {
+                            "type": "boolean",
+                            "description": "Trigger hook on pipeline events",
+                        },
+                        "wiki_page_events": {
+                            "type": "boolean",
+                            "description": "Trigger hook on wiki events",
+                        },
+                        "enable_ssl_verification": {
+                            "type": "boolean",
+                            "description": "Do SSL verification when triggering the hook",
+                        },
+                        "token": {
+                            "type": "string",
+                            "description": ("Secret token to validate received payloads; "
+                                            "this will not be returned in the response"),
+                        },
+                    },
+                    "required": ["url"],
+                    "additionalProperties": False,
                 },
+                "uniqueItems": True,
                 "_example": ("\n"
-                             "    foo: developer\n"
-                             "    bar: maintainer # one of guest, reporter, developer, maintainer, owner\n"),
+                             "    - url: http://example.com/api/trigger\n"
+                             "      push_events: true\n"
+                             "      push_events_branch_filter: \"\"\n"
+                             "      issues_events: true\n"
+                             "      confidential_issues_events: true\n"
+                             "      merge_requests_events: true\n"
+                             "      tag_push_events: true\n"
+                             "      note_events: true\n"
+                             "      confidential_note_events: true\n"
+                             "      job_events: true\n"
+                             "      pipeline_events: true\n"
+                             "      wiki_page_events: true\n"
+                             "      enable_ssl_verification: true\n"
+                             "      # token: T0k3N\n"),
             },
-            "unknown_members": {  # GitLabracadabra
+            "unknown_webhooks": {  # GitLabracadabra
                 "type": "string",
-                "description": "What to do with unknown members (`warn` by default).",
+                "description": "What to do with unknown webhooks (`warn` by default).",
                 "enum": ["warn", "delete", "remove", "ignore", "skip"],
             },
+            # From https://docs.gitlab.com/ee/api/projects.html#edit-project
+            "default_branch": {
+                "type": "string",
+                "description": "`master` by default",
+            },
+            "autoclose_referenced_issues": {
+                "type": "boolean",
+                "description": "Set whether auto-closing referenced issues on default branch",
+            },
+            # GitLabracadabra
+            "mirrors": {
+                "type": "array",
+                "description": "The list of project's mirrors",
+                "items": {
+                    "type": "object",
+                    "properties": {
+                        "url": {
+                            "type": "string",
+                            "description": "Repository URL",
+                        },
+                        "direction": {
+                            "type": "string",
+                            "description": "Mirror direction",
+                            "enum": ["pull", "push"],
+                        },
+                        "skip_ci": {
+                            "type": "boolean",
+                            "description": "Skip CI during push",
+                        }
+                    },
+                    "required": ["url"],
+                    "additionalProperties": False,
+                },
+                "uniqueItems": True,
+                "_example": ("\n"
+                             "    - url: https://gitlab.com/gitlabracadabra/gitlabracadabra.git\n"
+                             "      direction: pull # one of pull, push ; only first pull mirror is processed\n"
+                             # "      skip_ci: true # defaults to true\n"
+                             "  builds_access_level: disabled # Recommended to prevent triggering pipelines on push"),
+            },
+            # From https://docs.gitlab.com/ee/api/projects.html#edit-project
+            "mirror": {
+                "type": "boolean",
+                "description": "Enables pull mirroring in a project",
+            },
+            "import_url": {
+                "type": "string",
+                "description": "URL to import repository from",
+            },
+            "mirror_user_id": {
+                "type": "integer",
+                "description": "User responsible for all the activity surrounding a pull mirror event",
+            },
+            "mirror_overwrites_diverged_branches": {
+                "type": "boolean",
+                "description": "Pull mirror overwrites diverged branches",
+            },
+            "mirror_trigger_builds": {
+                "type": "boolean",
+                "description": "Pull mirroring triggers builds",
+            },
+            "only_mirror_protected_branches": {
+                "type": "boolean",
+                "description": "Only mirror protected branches",
+            },
             # From https://docs.gitlab.com/ee/api/protected_branches.html#protect-repository-branches
             # FIXME EE features: unprotect_access_level, allowed_to_push, allowed_to_merge, allowed_to_unprotect
             "protected_branches": {
@@ -474,11 +558,61 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
                 "description": "What to do with unknown protected tags (`warn` by default).",
                 "enum": ["warn", "delete", "remove", "ignore", "skip"],
             },
-            # https://docs.gitlab.com/ee/api/projects.html#archive-a-project
-            # https://docs.gitlab.com/ee/api/projects.html#unarchive-a-project
-            "archived": {
+            # From https://docs.gitlab.com/ee/api/branches.html#create-repository-branch
+            "branches": {
+                "type": "array",
+                "description": "The list of branches for a project. "
+                               "Branches are created in order.",
+                "items": {
+                    "type": "string",
+                },
+                "uniqueItems": True,
+                "_example": "\n    - master\n    - develop"
+            },
+            # From https://docs.gitlab.com/ee/api/projects.html#edit-project
+            "build_git_strategy": {
+                "type": "string",
+                "description": "The Git strategy",
+                "enum": ["fetch", "clone"],
+            },
+            "ci_default_git_depth": {
+                "type": "integer",
+                "description": "Default number of revisions for shallow cloning",
+            },
+            "build_timeout": {
+                "type": "integer",
+                "description": "The maximum amount of time in minutes that a job is able run (in seconds)",
+            },
+            "ci_config_path": {
+                "type": "string",
+                "description": "The path to CI config file",
+                "_example": 'debian/salsa-ci.yml'
+            },
+            "public_builds": {
                 "type": "boolean",
-                "description": "Archive or unarchive project",
+                "description": "If true, jobs can be viewed by non-project-members",
+            },
+            "auto_cancel_pending_pipelines": {
+                "type": "string",
+                "description": "Auto-cancel pending pipelines",
+                "enum": ["enabled", "disabled"],
+            },
+            "build_coverage_regex": {
+                "type": "string",
+                "description": "Test coverage parsing",
+            },
+            "auto_devops_enabled": {
+                "type": "boolean",
+                "description": "Enable Auto DevOps for this project",
+            },
+            "auto_devops_deploy_strategy": {
+                "type": "string",
+                "description": "Auto Deploy strategy",
+                "enum": ["continuous", "manual", "timed_incremental"],
+            },
+            "shared_runners_enabled": {
+                "type": "boolean",
+                "description": "Enable shared runners for this project",
             },
             # From https://docs.gitlab.com/ee/api/project_level_variables.html#create-variable
             "variables": {
@@ -618,43 +752,43 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
                 "description": "What to do with unknown milestones (`warn` by default).",
                 "enum": ["warn", "delete", "remove", "ignore", "skip"],
             },
-            # GitLabracadabra
-            "mirrors": {
-                "type": "array",
-                "description": "The list of project's mirrors",
-                "items": {
-                    "type": "object",
-                    "properties": {
-                        "url": {
-                            "type": "string",
-                            "description": "Repository URL",
-                        },
-                        "direction": {
-                            "type": "string",
-                            "description": "Mirror direction",
-                            "enum": ["pull", "push"],
-                        },
-                        "skip_ci": {
-                            "type": "boolean",
-                            "description": "Skip CI during push",
-                        }
-                    },
-                    "required": ["url"],
-                    "additionalProperties": False,
-                },
-                "uniqueItems": True,
-                "_example": ("\n"
-                             "    - url: https://gitlab.com/gitlabracadabra/gitlabracadabra.git\n"
-                             "      direction: pull # one of pull, push ; only first pull mirror is processed\n"
-                             # "      skip_ci: true # defaults to true\n"
-                             "  builds_access_level: disabled # Recommended to prevent triggering pipelines on push"),
+            # From https://docs.gitlab.com/ee/api/projects.html#edit-project
+            "issues_enabled": {
+                "type": "boolean",
+                "description": "Enable issues for this project",
+            },
+            "merge_requests_enabled": {
+                "type": "boolean",
+                "description": "Enable merge requests for this project",
+            },
+            "jobs_enabled": {
+                "type": "boolean",
+                "description": "Enable jobs for this project",
+            },
+            "wiki_enabled": {
+                "type": "boolean",
+                "description": "Enable wiki for this project",
+            },
+            "snippets_enabled": {
+                "type": "boolean",
+                "description": "Enable snippets for this project",
+            },
+            # Below are undocumented settings
+            "repository_storage": {
+                "type": "string",
+                "description": "Which storage shard the repository is on. Available only to admins",
+            },
+            "external_authorization_classification_label": {
+                "type": "string",
+                "description": "The classification label for the project",
             },
         },
         "additionalProperties": False,
     }
 
     IGNORED_PARAMS = ['initialize_with_readme', 'unknown_groups', 'unknown_labels', 'unknown_members',
-                      'unknown_milestones', 'unknown_protected_branches', 'unknown_protected_tags', 'unknown_variables']
+                      'unknown_milestones', 'unknown_protected_branches', 'unknown_protected_tags', 'unknown_variables',
+                      'unknown_webhooks']
 
     CREATE_KEY = 'name'
     CREATE_PARAMS = ['initialize_with_readme']
@@ -683,7 +817,7 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
     """
     def _process_archived(self, param_name, param_value, dry_run=False, skip_save=False):
         assert param_name == 'archived'  # noqa: S101
-        assert skip_save == False  # noqa: S101
+        assert not skip_save  # noqa: S101
 
         current_value = getattr(self._obj, param_name)
         if current_value != param_value:
@@ -705,7 +839,7 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
     """
     def _process_branches(self, param_name, param_value, dry_run=False, skip_save=False):
         assert param_name == 'branches'  # noqa: S101
-        assert skip_save == False  # noqa: S101
+        assert not skip_save  # noqa: S101
         if 'default_branch' in self._content and self._content['default_branch'] in self._get_current_branches():
             # Create from target default branch if it exists
             ref = self._content['default_branch']
@@ -741,7 +875,7 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
     """
     def _process_groups(self, param_name, param_value, dry_run=False, skip_save=False):
         assert param_name == 'groups'  # noqa: S101
-        assert skip_save == False  # noqa: S101
+        assert not skip_save  # noqa: S101
         param_value = deepcopy(param_value)
         unknown_groups = self._content.get('unknown_groups', 'warn')
         # We first check for already shared groups
@@ -801,7 +935,7 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
     """
     def _process_protected_branches(self, param_name, param_value, dry_run=False, skip_save=False):
         assert param_name == 'protected_branches'  # noqa: S101
-        assert skip_save == False  # noqa: S101
+        assert not skip_save  # noqa: S101
         unknown_protected_branches = self._content.get('unknown_protected_branches', 'warn')
         current_protected_branches = dict([[protected_branch.name, protected_branch]
                                           for protected_branch in self._obj.protectedbranches.list(all=True)])
@@ -862,7 +996,7 @@ class GitLabracadabraProject(GitLabracadabraObject, LabelsMixin, MembersMixin, M
     """
     def _process_protected_tags(self, param_name, param_value, dry_run=False, skip_save=False):
         assert param_name == 'protected_tags'  # noqa: S101
-        assert skip_save == False  # noqa: S101
+        assert not skip_save  # noqa: S101
         unknown_protected_tags = self._content.get('unknown_protected_tags', 'warn')
         try:
             current_protected_tags = dict([[protected_tag.name, protected_tag]
