@@ -392,3 +392,45 @@ class TestProject(TestCase):
         })
         obj.process()
         self.assertEqual(cass.all_played, True)
+
+    @my_vcr.use_cassette
+    def test_webhooks(self, cass):
+        obj = GitLabracadabraProject('memory', 'test/test_webhooks', {
+            'webhooks': [
+                {
+                    "url": "http://example.com/create_me",
+                    "push_events": False,
+                    "push_events_branch_filter": "master",
+                    "issues_events": True,
+                    "confidential_issues_events": True,
+                    "merge_requests_events": True,
+                    "tag_push_events": True,
+                    "note_events": True,
+                    "confidential_note_events": True,
+                    "job_events": True,
+                    "pipeline_events": True,
+                    "wiki_page_events": True,
+                    "enable_ssl_verification": False,
+                    # "repository_update_events": True,
+                },
+                {
+                    "url": "http://example.com/modify_me",
+                    "push_events": False,
+                    "push_events_branch_filter": "master",
+                    "issues_events": True,
+                    "confidential_issues_events": True,
+                    "merge_requests_events": True,
+                    "tag_push_events": True,
+                    "note_events": True,
+                    "confidential_note_events": True,
+                    "job_events": True,
+                    "pipeline_events": True,
+                    "wiki_page_events": True,
+                    "enable_ssl_verification": False,
+                    # "repository_update_events": True,
+                },
+            ],
+            'unknown_webhooks': 'delete',
+        })
+        obj.process()
+        self.assertEqual(cass.all_played, True)
